@@ -270,7 +270,7 @@ sub forgeHeadersInit {
         {
             my %tmp = %{ $args->{exportedHeaders}->{$vhost} };
             foreach ( keys %tmp ) {
-                $tmp{$_} =~ s/\$(\w+)/\$datas->{$1}/g;
+                $tmp{$_} =~ s/\$(?!ENV)(\w+)/\$datas->{$1}/g;
                 $tmp{$_} = $self->regRemoteIp( $tmp{$_} );
             }
 
@@ -350,7 +350,7 @@ sub postUrlInit {
                 # Build string for URI::query_form
                 my $tmp;
                 foreach ( keys %postdata ) {
-                    $postdata{$_} =~ s/\$(\w+)/\$datas->{$1}/g;
+                    $postdata{$_} =~ s/\$(?!ENV)(\w+)/\$datas->{$1}/g;
                     $postdata{$_} = "'$postdata{$_}'"
                       if ( $postdata{$_} =~ /^\w+$/ );
                     $tmp .= "'$_'=>$postdata{$_},";
@@ -474,8 +474,8 @@ sub conditionSub {
 
     # Replace some strings in condition
     $cond =~ s/\$date/&POSIX::strftime("%Y%m%d%H%M%S",localtime())/e;
-    $cond =~ s/\$(\w+)/\$datas->{$1}/g;
-    $cond =~ s/\$datas->{vhost}/\$apacheRequest->hostname/g;
+    $cond =~ s/\$(?!ENV)(\w+)/\$datas->{$1}/g;
+    $cond =~ s/\$datas->\{vhost\}/\$apacheRequest->hostname/g;
 
     my $jail = Lemonldap::NG::Handler::Main::Jail->new(
         'safe'            => $self->safe,
